Package com.google.cloud.spanner
Class Instance
java.lang.Object
com.google.cloud.spanner.InstanceInfo
com.google.cloud.spanner.Instance
Represents a Cloud Spanner Instance.
Instance adds a layer of service related
functionality over InstanceInfo.-
Nested Class Summary
Nested ClassesNested classes/interfaces inherited from class com.google.cloud.spanner.InstanceInfo
InstanceInfo.InstanceField, InstanceInfo.State -
Method Summary
Modifier and TypeMethodDescriptioncreateDatabase(String databaseId, Iterable<String> statements) Creates a new database in this instance.voiddelete()Returns the backup with the given id on this instance.getDatabase(String databaseId) Returns the IAMPolicyfor this instance.listBackupOperations(Options.ListOption... options) Returns the long-running backup operations on this instance.listBackups(Options.ListOption... options) Returns the backups belonging to this instance.listDatabaseOperations(Options.ListOption... options) Returns the long-running database operations on this instance.listDatabases(Options.ListOption... options) reload()setIAMPolicy(Policy policy) Updates the IAM policy for this instance and returns the resulting policy.testIAMPermissions(Iterable<String> permissions) Tests for the given permissions on this instance for the caller.update(InstanceInfo.InstanceField... fieldsToUpdate) Methods inherited from class com.google.cloud.spanner.InstanceInfo
equals, getAutoscalingConfig, getCreateTime, getDisplayName, getEdition, getId, getInstanceConfigId, getLabels, getNodeCount, getProcessingUnits, getState, getUpdateTime, hashCode, newBuilder, toString
-
Method Details
-
reload
-
delete
public void delete() -
update
public OperationFuture<Instance,UpdateInstanceMetadata> update(InstanceInfo.InstanceField... fieldsToUpdate) -
listDatabases
-
getDatabase
-
createDatabase
public OperationFuture<Database,CreateDatabaseMetadata> createDatabase(String databaseId, Iterable<String> statements) throws SpannerException Creates a new database in this instance.- Parameters:
databaseId- the id of the database which will be created. It must conform to the regular expression [a-z][a-z0-9_\-]*[a-z0-9] and be between 2 and 30 characters in lengthstatements- DDL statements to run while creating the database, for exampleCREATE TABLE MyTable ( ... ). This should not includeCREATE DATABASEstatement.- Throws:
SpannerException
-
listBackups
Returns the backups belonging to this instance. -
getBackup
Returns the backup with the given id on this instance. -
listDatabaseOperations
Returns the long-running database operations on this instance. -
listBackupOperations
Returns the long-running backup operations on this instance. -
getIAMPolicy
Returns the IAMPolicyfor this instance. -
setIAMPolicy
Updates the IAM policy for this instance and returns the resulting policy. It is highly recommended to first get the current policy and base the updated policy on the returned policy. SeePolicy.Builder.setEtag(String)for information on the recommended read-modify-write cycle. -
testIAMPermissions
Tests for the given permissions on this instance for the caller.- Parameters:
permissions- the permissions to test for. Permissions with wildcards (such as '*', 'spanner.*', 'spanner.instances.*') are not allowed.- Returns:
- the subset of the tested permissions that the caller is allowed.
-
toBuilder
- Overrides:
toBuilderin classInstanceInfo
-