Package com.google.cloud.spanner
Class SessionPoolOptions
java.lang.Object
com.google.cloud.spanner.SessionPoolOptions
Deprecated.
The Spanner Java client uses a single multiplexed session. All options related to the
session pool are no longer functional and will be removed in a future version.
Options for the session pool used by
DatabaseClient.-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classDeprecated.Builder for creating SessionPoolOptions. -
Method Summary
Modifier and TypeMethodDescriptionbooleanDeprecated.intDeprecated.intDeprecated.Use a higher value forSessionPoolOptions.Builder.setMinSessions(int)instead of setting this option.intDeprecated.intDeprecated.org.threeten.bp.DurationDeprecated.This method is obsolete.Deprecated.booleanDeprecated.protected booleanDeprecated.booleanDeprecated.protected static BooleanDeprecated.booleanDeprecated.floatDeprecated.This value is no longer used.inthashCode()Deprecated.booleanDeprecated.booleanDeprecated.booleanDeprecated.booleanDeprecated.static SessionPoolOptions.BuilderDeprecated.Deprecated.
-
Method Details
-
equals
Deprecated. -
hashCode
public int hashCode()Deprecated. -
toBuilder
Deprecated. -
getMinSessions
Deprecated. -
getMaxSessions
Deprecated. -
getMaxIdleSessions
Deprecated.Use a higher value forSessionPoolOptions.Builder.setMinSessions(int)instead of setting this option. -
getWriteSessionsFraction
Deprecated.This value is no longer used. The session pool does not prepare any sessions for read/write transactions. Instead, a transaction will be started by including a BeginTransaction option with the first statement of a transaction. This method may be removed in a future release. -
getKeepAliveIntervalMinutes
Deprecated. -
getRemoveInactiveSessionAfter
@ObsoleteApi("Use getRemoveInactiveSessionAfterDuration() instead") public org.threeten.bp.Duration getRemoveInactiveSessionAfter()Deprecated.This method is obsolete. UsegetRemoveInactiveSessionAfterDuration()instead. -
getRemoveInactiveSessionAfterDuration
Deprecated. -
isFailIfPoolExhausted
Deprecated. -
isBlockIfPoolExhausted
Deprecated. -
isAutoDetectDialect
public boolean isAutoDetectDialect()Deprecated. -
isTrackStackTraceOfSessionCheckout
Deprecated. -
getUseMultiplexedSession
@InternalApi public boolean getUseMultiplexedSession()Deprecated. -
getUseMultiplexedSessionBlindWrite
@InternalApi protected boolean getUseMultiplexedSessionBlindWrite()Deprecated. -
getUseMultiplexedSessionForRW
@InternalApi public boolean getUseMultiplexedSessionForRW()Deprecated. -
getUseMultiplexedSessionPartitionedOps
@InternalApi public boolean getUseMultiplexedSessionPartitionedOps()Deprecated. -
getUseMultiplexedSessionFromEnvVariablePartitionedOps
Deprecated. -
newBuilder
Deprecated.
-