Uses of Class
com.google.cloud.spanner.CommitResponse
Packages that use CommitResponse
Package
Description
A client for Cloud Spanner - A no-compromise relational database service.
Internal API for Google Cloud Spanner.
-
Uses of CommitResponse in com.google.cloud.spanner
Methods in com.google.cloud.spanner that return CommitResponseModifier and TypeMethodDescriptionTransactionManager.getCommitResponse()Returns theCommitResponseof this transaction.TransactionRunner.getCommitResponse()Returns theCommitResponseof this transaction.DatabaseClient.writeAtLeastOnceWithOptions(Iterable<Mutation> mutations, Options.TransactionOption... options) Writes the given mutations atomically to the database without replay protection.DatabaseClient.writeWithOptions(Iterable<Mutation> mutations, Options.TransactionOption... options) Writes the given mutations atomically to the database with the given options.Methods in com.google.cloud.spanner that return types with arguments of type CommitResponseModifier and TypeMethodDescriptionAsyncRunner.getCommitResponse()Returns theCommitResponseof this transaction.AsyncTransactionManager.getCommitResponse()Returns theCommitResponseof this transaction.DelayedAsyncRunner.getCommitResponse()DelayedAsyncTransactionManager.getCommitResponse() -
Uses of CommitResponse in com.google.cloud.spanner.connection
Methods in com.google.cloud.spanner.connection that return CommitResponse