Uses of Interface
com.google.cloud.spanner.Options.ReadQueryUpdateTransactionOption
Packages that use Options.ReadQueryUpdateTransactionOption
Package
Description
A client for Cloud Spanner - A no-compromise relational database service.
Internal API for Google Cloud Spanner.
-
Uses of Options.ReadQueryUpdateTransactionOption in com.google.cloud.spanner
Methods in com.google.cloud.spanner that return Options.ReadQueryUpdateTransactionOptionModifier and TypeMethodDescriptionOptions.clientContext(RequestOptions.ClientContext clientContext) Specifying this will add the given client context to the request.Options.priority(Options.RpcPriority priority) Specifies the priority to use for the RPC.Specifying this will cause the reads, queries, updates and writes operations statistics collection to be grouped by tag. -
Uses of Options.ReadQueryUpdateTransactionOption in com.google.cloud.spanner.connection
Methods in com.google.cloud.spanner.connection that return Options.ReadQueryUpdateTransactionOption