Uses of Class
com.google.cloud.spanner.SessionPoolOptions.Builder
Packages that use SessionPoolOptions.Builder
Package
Description
A client for Cloud Spanner - A no-compromise relational database service.
-
Uses of SessionPoolOptions.Builder in com.google.cloud.spanner
Methods in com.google.cloud.spanner that return SessionPoolOptions.BuilderModifier and TypeMethodDescriptionstatic SessionPoolOptions.BuilderSessionPoolOptions.newBuilder()Deprecated.SessionPoolOptions.Builder.setAcquireSessionTimeout(org.threeten.bp.Duration acquireSessionTimeout) Deprecated.SessionPoolOptions.Builder.setAcquireSessionTimeoutDuration(Duration acquireSessionTimeout) Deprecated.SessionPoolOptions.Builder.setAutoDetectDialect(boolean autoDetectDialect) Sets whether the client should automatically execute a background query to detect the dialect that is used by the database or not.SessionPoolOptions.Builder.setBlockIfPoolExhausted()Deprecated.SessionPoolOptions.Builder.setExperimentalHost()SessionPoolOptions.Builder.setFailIfPoolExhausted()Deprecated.SessionPoolOptions.Builder.setKeepAliveIntervalMinutes(int intervalMinutes) Deprecated.SessionPoolOptions.Builder.setMaxIdleSessions(int maxIdleSessions) Deprecated.SessionPoolOptions.Builder.setMaxSessions(int maxSessions) Deprecated.SessionPoolOptions.Builder.setMinSessions(int minSessions) Deprecated.SessionPoolOptions.Builder.setRemoveInactiveSessionAfter(org.threeten.bp.Duration duration) Deprecated.SessionPoolOptions.Builder.setRemoveInactiveSessionAfterDuration(Duration duration) Deprecated.SessionPoolOptions.Builder.setTrackStackTraceOfSessionCheckout(boolean trackStackTraceOfSessionCheckout) Deprecated.SessionPoolOptions.Builder.setWaitForMinSessions(org.threeten.bp.Duration waitForMinSessions) This method is obsolete.SessionPoolOptions.Builder.setWaitForMinSessionsDuration(Duration waitForMinSessions) If greater than zero, waits for the session pool to have at leastSessionPoolOptions.minSessionsbefore returning the database client to the caller.SessionPoolOptions.Builder.setWarnAndCloseIfInactiveTransactions()Deprecated.SessionPoolOptions.Builder.setWarnIfInactiveTransactions()Deprecated.SessionPoolOptions.Builder.setWriteSessionsFraction(float writeSessionsFraction) Deprecated.This configuration value is no longer in use.SessionPoolOptions.toBuilder()Deprecated.
setMinSessions(int)instead of using this configuration option.